# Capability Boost Plan

This page is currently maintained in Chinese first.

- Chinese page: [能力补强路线图（2026-03 本地状态更新）](../../zh/advanced/capability_boost_plan.md)
- Related docs:
  - [Data Feed Adapter Spec](data_feed_adapter_spec.md)
  - [Analyzer Plugin Spec](analyzer_plugin_spec.md)
  - [TA-Lib Top20 Plan](talib_top20_plan.md)
